@@ -3,7 +3,6 @@
 #undef sha_384_512
 #undef W64
 #undef strto64
-#undef digcpy64
 #undef sha512
 #undef H0384
 #undef H0512
@@ -66,20 +65,22 @@ C64(0xa54ff53a5f1d36f1), C64(0x510e527fade682d1), C64(0x9b05688c2b3e6c1f),
 C64(0x1f83d9abfb41bd6b), C64(0x5be0cd19137e2179)
 };
 
-/* w64mem: writes 64-bit word to memory in big-endian order */
-static void w64mem(mem, w64)
-unsigned char *mem;
-W64 w64;
+static W64 H0512224[8] =	/* SHA-512/224 initial hash value */
 {
-	int i;
+C64(0x8c3d37c819544da2), C64(0x73e1996689dcd4d6), C64(0x1dfab7ae32ff9c82),
+C64(0x679dd514582f9fcf), C64(0x0f6d2b697bd44da8), C64(0x77e36f7304c48942),
+C64(0x3f9d85a86a1d36c8), C64(0x1112e6ad91d692a1)
 
-	for (i = 0; i < 8; i++)
-		*mem++ = (unsigned char) (SR64(w64, 56 - i * 8) & 0xff);
-}
+};
+static W64 H0512256[8] =	/* SHA-512/256 initial hash value */
+{
+C64(0x22312194fc2bf72c), C64(0x9f555fa3c84c64c2), C64(0x2393b86b6f53b151),
+C64(0x963877195940eabd), C64(0x96283ee2a88effe3), C64(0xbe5e1e2553863992),
+C64(0x2b0199fc2c85b8aa), C64(0x0eb72ddc81c52ca2)
+};
 
 /* strto64: converts hex string to a 64-bit word */
-static W64 strto64(s)
-char *s;
+static W64 strto64(char *s)
 {
 	char str[2] = {0, 0};
 	W64 u = C64(0);
@@ -89,20 +90,7 @@ char *s;
 	return(u);
 }
 
-/* digcpy64: writes current state to digest buffer */
-static void digcpy64(s)
-SHA *s;
-{
-	unsigned int i;
-	W64 *p = (W64 *) s->H;
-
-	for (i = 0; i < 8; i++)
-		w64mem(s->digest + i * 8, *p++);
-}
-
-static void sha512(s, block)	/* SHA-384/512 transform */
-SHA *s;
-unsigned char *block;
+static void sha512(SHA *s, unsigned char *block) /* SHA-384/512 transform */
 {
 	W64 a, b, c, d, e, f, g, h, T1, T2;
 	SHA_STO_CLASS W64 W[80];
